/*
 * oggLength is a command line tool, to return the length of an ogg file
 *
 * Copyright (C) 2008 Joern Seger
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

#include <iostream>
#include <string>
#include <cstdlib>

#include "fileRepository.h"
#include "streamSerializer.h"

void printHelpScreen(std::string& progName)
{
  std::cerr << "usage: " << progName << " <inputFile> \n";
}

int main(int argc, char* argv[])
{

  std::string inputFile;
  std::string programName(argv[0]);

  int opt;
  while ((opt = getopt(argc, argv, "h")) != EOF)

  switch (opt) {

    case 'h':
    printHelpScreen(programName);
    exit(-1);

  }

  argc -= optind;
  argv += optind;

  if (argc == 1)
    inputFile = std::string(argv[0]);
  else {
    printHelpScreen(programName);
    exit(-1);
  }

  /* create the stream serializer */
  StreamSerializer streamSerializer;

  /* open the file */
  if (!streamSerializer.open(inputFile)) {
    std::cerr << "Error: can not open file <"<<inputFile<<">\n";
    exit(-1);
  }

  /* create the headers */
  std::vector<StreamConfig> streamConfigList;
  streamSerializer.getStreamConfig(streamConfigList);

//  for (uint32 i(0); i<streamConfigList.size(); ++i) {
//    std::cerr << streamConfigList[i].parameter->toString();
//  }

  OggPacket packet;
  double time;
  double retTime(-1);

  /* copy the stream if the packets are within the cut area
   * and the first video keyframe has been found */
  while(1==1) {

    time = streamSerializer.getNextPacket(packet);

    if (time < 0) {
      std::cout << (int)(retTime*1000) << std::endl;
      return((int)(retTime*1000));
    }
    else
      retTime = time;

  }

}
